@@ -85,7 +85,6 @@ extern int permbancount(char *);
 extern int topiccount(char *);
 extern int nthmode(char *, int);
 extern int userleft(char *, char *, char *);
-extern int sameuser(char *, char *, char *, char *);
 extern int changeuser(char *, char *, int, int, int);
 extern int whichctcp(char *);
 extern int whichcommand(char *, int);
@@ -149,7 +148,7 @@ extern struct topic *insertnewtopic(char *, char *, char *, int);
 extern struct topic *edittopic(char *, char *, char *, int);
 extern struct chanuser *getrandomuser(char *);
 extern struct ls_wrapstruct *addnew_ls(struct ls_wrapstruct *, time_t, char *, char *, char *);
-extern time_t lastoff(char *, char *);
+extern time_t lastoff(char *, char *, char *);
 extern void sendadverts(char *, char *, char *);
 extern void deladverts(char *, char *);
 extern void resetparts(char *, char *, char *);
@@ -184,7 +183,6 @@ extern void sethostquerystatus(char *, int);
 extern void iwaskicked(char *);
 extern void banuser(char *, char *);
 extern void unbanuser(char *, char *);
-extern void bankickuser(char *, char *, char *);
 extern void kickuser(char *, char *, char *);
 extern void sendreply(char *, int, int, int, char *);
 extern void sendchannelnotice(char *, int, char *);
@@ -225,3 +223,4 @@ extern void parsectcp(char *, char *, int, char *);
 extern void nstats(char *, int, char *, char *);
 extern void wall(char *, char *, char *, char *);
 extern void cleanautheds(char *);
+extern void listchanusers(void);
