@@ -43,6 +43,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
   #include <ctype.h> 
 #endif
 
+#ifdef HAVE_LOCALE_H
+  #include <locale.h>
+#endif
+
 #include <errno.h>
 #include <unistd.h>
 #include <netdb.h>
@@ -304,7 +308,7 @@ enum OER_ADVERT_TYPES {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-32, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-33, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
