@@ -479,15 +479,17 @@ void parseirc(char *serveroutput)
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
 		strncpy(channel, params, CHANLEN);
-		addnewpart(channel, mystate->now, nick, host);
-		if(!userleft(channel, nick, host)) {
-			oer_debug(OER_DEBUG_INFO, "parseirc(PART)->userleft() returned NULL\n");
-		}
 		if(isme(nick)) {
+			/* no reason to remove from channel, we will just
+			   init it */
 			initchannel(channel);
 			iwaskicked(channel);
 			return;
 		}
+		addnewpart(channel, mystate->now, nick, host);
+		if(!userleft(channel, nick, host)) {
+			oer_debug(OER_DEBUG_INFO, "parseirc(PART)->userleft() returned NULL\n");
+		}
 		if(usersonchan(channel) == 1 && !amiop(channel)) {
 			oer_debug(OER_DEBUG_INFO, "parseirc(PART)->cycling %s to gain ops\n", channel);
 			snprintf(outstring, STRINGLEN, "PART %s\n", channel);
@@ -559,6 +561,11 @@ void parseirc(char *serveroutput)
 		if(!userleft(channel, target, cu->host)) {
 			oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->userleft() returned NULL\n");
 		}
+		if(usersonchan(channel) == 1 && !amiop(channel)) {
+			oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->cycling %s to gain ops\n", channel);
+			snprintf(outstring2, WRITE_BUFFER_LENGTH, "PART %s\n", channel);
+			addnewtimed(mystate->now, OER_TIMED_IRC_COMMAND, OER_TIMED_IRC_COMMAND_DUMMY, outstring2, NULL, NULL, NULL);
+		}
 		listchanusers();
 		return;
 	}
@@ -676,6 +683,10 @@ void parseirc(char *serveroutput)
 
 					}
 				}
+				/* sync bans. if a user has set ban *@*.se and there is a
+				   permban *@*.swipnet.se, the latter has to be re-insert when
+				   the former is manually removed */
+				syncbans(channel);
 				break;
 			}
 			if((deops > OER_MASSMODE_LIMIT) && (index(host, '@') != NULL) && !isme(nick)) {
